==> haskell-data-accessor-transformers-0.2.1.7-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-accessor-transformers
version:              0.2.1.7
visibility:           public
id:                   data-accessor-transformers-0.2.1.7-D2ASC7lDTpl6KEQd8npoPq
key:                  data-accessor-transformers-0.2.1.7-D2ASC7lDTpl6KEQd8npoPq
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://www.haskell.org/haskellwiki/Record_access
synopsis:             Use Accessor to access state in transformers State monad
description:          Use Accessor to access state in transformers State monad
category:             Data
abi:                  af8f625a1523e1762abd6db806543e1d
exposed:              True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State

hidden-modules:       Data.Accessor.Monad.Trans.Example
import-dirs:
    /usr/lib/ghc-8.10.1/site-local/data-accessor-transformers-0.2.1.7

library-dirs:
    /usr/lib/ghc-8.10.1/site-local/data-accessor-transformers-0.2.1.7

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.1/data-accessor-transformers-0.2.1.7

hs-libraries:         HSdata-accessor-transformers-0.2.1.7-D2ASC7lDTpl6KEQd8npoPq
depends:
    base-4.14.0.0 data-accessor-0.2.3-Fj2GxYYXr1GBdVutHQarJO
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock

haddock-html:         /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-accessor-transformers-0.2.1.7-20-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-accessor-transformers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-accessor-transformers
version:              0.2.1.7
visibility:           public
id:                   data-accessor-transformers-0.2.1.7-DXVc4ZdeImk3Y28EoSK6h7
key:                  data-accessor-transformers-0.2.1.7-DXVc4ZdeImk3Y28EoSK6h7
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             http://www.haskell.org/haskellwiki/Record_access
synopsis:             Use Accessor to access state in transformers State monad
description:          Use Accessor to access state in transformers State monad
category:             Data
abi:                  556eb7d0cbb675b060283a04b23982d6
exposed:              True
exposed-modules:
    Data.Accessor.Monad.Trans.RWS Data.Accessor.Monad.Trans.State

hidden-modules:       Data.Accessor.Monad.Trans.Example
import-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-accessor-transformers-0.2.1.7

library-dirs:
    /usr/lib/ghc-8.10.2/site-local/data-accessor-transformers-0.2.1.7

dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.2/data-accessor-transformers-0.2.1.7

hs-libraries:         HSdata-accessor-transformers-0.2.1.7-DXVc4ZdeImk3Y28EoSK6h7
depends:
    base-4.14.1.0 data-accessor-0.2.3-CK4QQ8PO1tYBVDSgY4rS1S
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-data-accessor-transformers/html/data-accessor-transformers.haddock

haddock-html:         /usr/share/doc/haskell-data-accessor-transformers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
